@echo off
goto BeginScript

A general-purpose queueing script by Serge Winitzki (winitzki@geocities.com).
I got tired of all those multi-megabyte executables for playing MIDI files in
a queue and wrote this batch file. The script can be used to queue multimedia
files of any kind, given the right file associations (see instructions).


:BeginScript
:The script needs the TEMP variable pointing to a temporary space.
:Set it here if you don't have it, for example,
:set TEMP=c:\TEMP

:compatibility: DOS 5.x and up, except for the start command (see below)

:if no arguments are given, we start playing the queue unless it's being played
: (if it doesn't exist, we just initialize queue to allow silent editting)
: if it's playing, we delete the queue file and the lock file (so that it'll stop).
: if files are given as arguments, we add them to the queue
: but start playing only if the queue file is not already there.
: this is both to avoid conflict with an already playing queue
: and to allow updating the queue without starting it.
:
:if a list file is given (file:), we append it verbatim to the queue (undocumented)
: can be used to associate playlist files with "Queuer file: %1"
: but actually if we keep playlist files as just .bat files, we don't need it
: and can drop them on Queuer directly.

:this file will be our temporary queue list, executable by itself
set MQFile=%TEMP%\QueList.bat
if "%1" == "" goto NoArgs
if "%1" == "file:" goto ScriptFile
if "%1" == "_Initialize" goto Initialize
:now we know that we have some files as arguments
if not exist %MQFile% goto NewQueue
:now we know that the queue already exists, and we just need to add a line to it

:HERE is the ONLY line that depends on what we are queueing and uses the "start" command
:use default file association, so we can add any files to the queue
:the kludge to avoid problems with spaces in file names, damn command.com, it still doesn't work
echo start/w /m "%1%2%3%4%5%6%7%8%9" >> %MQFile%
:we don't start playing it here, just add to the queue. If it is being played, we shouldn't start again
: and if it isn't, we leave it alone (user just wants to update a queue)
goto done

:Initialize the queue file
if exist %MQFile%.playing del %MQFile%.playing
echo @echo off > %MQFile%
goto done

:NewQueue - need to create a new queue file, add our line, and start playing it
:this is executed only once per playing cycle
call %0 _Initialize
:add our line now
call %0 %1 %2 %3 %4 %5 %6 %7 %8 %9
:play it now
call %0
goto done

:NoArgs given
if exist %MQFile% goto StartPlaying
goto Initialize

:StartPlaying - queue exists
:check that it isn't being played, and initialize if it is
if exist %MQFile%.playing goto Initialize
:raise the playing flag
echo. > %MQFile%.playing
:play it
call %MQFile%
:all done, clean up
del %MQFile%.playing
del %MQFile%
:uncomment the following line if desired. It will beep after the queue is done.
:echo Queue finished.
goto done

:ScriptFile given in %2
if "%2"=="" goto NoScript
if not exist %2 goto NoScript
if not exist %MQFile% call %0 _Initialize
if "%2" == "%MQFile" goto StartPlaying
copy %MQFile% + %2
call %0
goto done

:NoScript file found
echo Problem: script file "%2" was not found.
goto PrintHelp

:PrintHelp message
echo This program adds a file to the MIDI queue.
echo Usage:	%0 file: filename
echo 		add a script file to the queue
echo 	%0 path\filename [...] list: path\wildcard [...]
echo 		add some files to the queue
goto done

:done
